@@ -5,6 +5,8 @@ class Directory:
     TESS = '.tess'
     DEBUG_SOLUTIONS = '.tess/debug/src'
     DEBUG_BUILD = '.tess/debug/build'
+    CUSTOM_CONFIG_LINUX = '~/.config/tess'
+    CUSTOM_CONFIG_MAC = '~/Library/Application\\ Support/Tess'
 
     @staticmethod
     def init():
